OC.L10N.register(
    "mail",
    {
    "Mail" : "메일",
    "Error while loading the accounts." : "계정을 불러오는 중 오류가 발생했습니다.",
    "Error while loading the selected account." : "선택한 계정을 불러오는 중 오류가 발생했습니다.",
    "Loading {folder}" : "{folder} 불러오는 중...",
    "Searching for {query}" : "{query} 검색",
    "Error while deleting message." : "메시지를 삭제하는 중 오류가 발생했습니다.",
    "Forwarded message" : "전달된 메시지",
    "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
    "Attachments saved to Files." : "첨부 파일이 클라우드에 저장되었습니다.",
    "Attachment saved to Files." : "첨부 파일이 클라우드에 저장되었습니다.",
    "Error while saving attachments to Files." : "첨부 파일을 클라우드에 저장하는 중 오류가 발생했습니다.",
    "Error while saving attachment to Files." : "첨부 파일을 클라우드에 저장하는 중 오류가 발생했습니다.",
    "Message flag could not be set." : "메시지 플래그를 설정할 수 없습니다.",
    "Could not move message." : "메시지를 이동할 수 없습니다.",
    "Invalid account" : "잘못된 계정",
    "Invalid folder" : "잘못된 폴더",
    "Unknown error" : "알 수 없는 오류",
    "All inboxes" : "모든 받은 편지함",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
    "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
    "We couldn’t load your message" : "메시지를 불러올 수 없음",
    "Unable to load the desired message" : "원하는 메시지를 불러올 수 없음",
    "There was a problem loading the message" : "메시지를 불러오는 중 문제가 발생했습니다",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Show all folders" : "모든 폴더 보기",
    "Collapse folders" : "폴더 접기",
    "Error while deleting account." : "계정을 삭제하는 중 오류가 발생했습니다.",
    "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
    "Reply" : "답장",
    "Send" : "보내기",
    "Sending …" : "보내는 중...",
    "Message sent!" : "메시지를 보냈습니다!",
    "Server error" : "서버 오류",
    "An unknown error occurred" : "알 수 없는 오류가 발생했습니다",
    "Opening HTML drafts is not supported yet." : "HTML 임시 보관 메시지를 여는 것은 지원되지 않습니다.",
    "Draft saved!" : "임시 보관함에 저장했습니다!",
    "you" : "나",
    "Send message to {email}" : "{email}(으)로 이메일 보내기",
    "No writable calendars found" : "쓰기 가능한 달력을 찾을 수 없음",
    "Error while importing the calendar event" : "달력 이벤트를 가져 오는 중 오류 발생",
    "Error while downloading calendar event" : "달력 이벤트 다운로드 중 오류 발생",
    "Error while loading messages." : "메시지를 불러오는 중 오류가 발생했습니다.",
    "Inbox" : "받은 편지함",
    "Sent" : "보낸 편지함",
    "Drafts" : "임시 보관함",
    "Archive" : "보관 편지함",
    "Trash" : "휴지통",
    "Junk" : "스팸 메일함",
    "All" : "전체 편지함",
    "Favorites" : "즐겨찾기",
    "Creating account failed: " : "계정 생성 실패: ",
    "Auto detect failed. Please use manual mode." : "자동 감지가 실패했습니다. 수동 모드를 사용하십시오.",
    "Delete permanently" : "영구히 삭제",
    "& others" : "및 그 외",
    "Error loading message" : "메시지 불러오기 오류",
    "Settings" : "설정",
    "Forwarding to %s" : "%s 전달",
    "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
    "Redirect" : "리디렉션",
    "The link leads to %s" : "링크는 %s(으)로 연결",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
    "Continue to %s" : "%s(으)로 이동",
    "Delete account" : "계정 삭제",
    "New message" : "새로운 메시지",
    "Account Settings" : "계정 설정",
    "Aliases" : "별칭",
    "Mail address" : "메일 주소",
    "Display Name" : "표시 이름",
    "Save" : "저장",
    "Connect your mail account" : "메일 계정에 연결",
    "Name" : "이름",
    "Mail Address" : "메일 주소",
    "Password" : "암호",
    "Manual configuration" : "직접 설정",
    "IMAP Host" : "IMAP 호스트",
    "IMAP security" : "IMAP 보안",
    "None" : "없음",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 포트",
    "IMAP User" : "IMAP 사용자",
    "IMAP Password" : "IMAP 암호",
    "SMTP Host" : "SMTP 호스트",
    "SMTP security" : "SMTP 보안",
    "SMTP Port" : "SMTP 포트",
    "SMTP User" : "SMTP 사용자",
    "SMTP Password" : "SMTP 암호",
    "Connect" : "연결",
    "from" : "보낸 사람",
    "to" : "받는 사람",
    "cc" : "참조",
    "bcc" : "숨은 참조",
    "Subject" : "제목",
    "Save all to Files" : "모두 저장",
    "Add mail account" : "메일 계정 추가",
    "No search results for" : "다음에 대한 검색 결과 없음",
    "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
    "Show images from this sender" : "이 발신자의 사진 표시",
    "Forward" : "전달",
    "Import into calendar" : "달력으로 가져오기",
    "Download attachment" : "첨부 파일 다운로드",
    "Save to Files" : "파일에 저장"
},
"nplurals=1; plural=0;");
